## 0.3.0 (February 18, 2024)
  - Fix official document site issue.
  - Add remaining sensors from the OI interface spec to the sensors dict. Create request functions to better support encoder usage. Update examples and README.

## 0.2.0 (July 15, 2022)
  - implemented API to get Sensor Packets
  - update doc system

## 0.1.5 (April 10, 2021)
  - Merge pull request #17 from AtsushiSakai/issue16
  - fix VERSION file not included issue
  - added automatic releases function for bump_version.sh
  - Issue #18 Replace np.deg2rad(x) to math.radians(x) in examples and docs
  - Replace sys.exit(1) to exception chaining for ability catch and recovery

## 0.1.4 (April 06, 2021)
  - Merge pull request #15 from AtsushiSakai/issue_11
  - add release script
  - Merge pull request #14 from process1183/serialexception
  - [#13] Check for the serial connection in the destructor
  - Fix typo in SerialException message.
  - [#13] Fix for SerialException NameError

## 0.1.3 (March 22, 2021)
  - Merge pull request #9 from process1183/drive_fix
  - [#8] Fix send_drive_direct() and send_drive_pwm() methods
  - Merge pull request #7 from AtsushiSakai/issue_6
  - update setup.py
  - fix setup py

## 0.1.2 (January 28, 2021)
  - Merge pull request #4 from hirohashi/patch-1
  - Modification of change_mode_to_full function.

## 0.1.1 (September 15, 2019)

- Release v0.1.1


## 0.1.0 (September 15, 2019)
  - update README
  - preparing for first release
  - release play song2
  - keep implement
  - update docs
  - keep implement
  - keep implement
  - add icon to the doc
  - add icon
  - improve document
  - update README
  - update README
  - Create FUNDING.yml
  - add doc setting
  - move function working
  - Initial commit

